(explanation)=

# Explanation

Conceptual explanations of morphometric methods and theory.

## Overview

```{eval-rst}
.. toctree::
    :maxdepth: 1

    morphometrics
```

## Landmark-based Morphometrics

```{eval-rst}
.. toctree::
    :maxdepth: 1

    landmark
    semilandmarks
```

## Harmonic-based Morphometrics

```{eval-rst}
.. toctree::
    :maxdepth: 1

    harmonic
```

## Visualization

```{eval-rst}
.. toctree::
    :maxdepth: 1

    visualization
```
